# TkEnhanced

TkEnhanced is a Python package that extends Tkinter with custom widgets and additional functionality for a modern look.

## Installation

You can install TkEnhanced using pip:

```bash
pip install TkEnhanced
